function rheodyne232objdisconnect(serialObject)
% RHEODYNE232OBJDISCONNECT terminates communication with Rheodyne valves
% rheodyne232objdisconnect(serialObject) terminates communication with
% Rheodyne valves, given serialObject as a valid Rheodyne serial object
% (generated by rheodyne232obj).

% e.g. rheodyne232objdisconnect(serialObject) - terminates
% communication with the Rheodyne valve.

% Range:

% serialObject = valid serial port object


% checks the number of arguments
error(nargchk(1, 1, nargin))

% error handling
if ~isa(serialObject, 'serial') || ~isvalid(serialObject) || ~strcmp(serialObject.Status, 'open')
    % errors
    error('serialObject must be a valid open serial object.')
end

% if the timer object is present, stop then delete it
if isfield(serialObject.UserData, 'timerObject')
    % if its running, stop it
    if strcmp(serialObject.UserData.timerObject, 'on')
        % stop it
        stop(serialObject.UserData.timerObject)
    end
    
    % delete it
    delete(serialObject.UserData.timerObject)
end

% closes communication conventionally
fclose(serialObject)

% deletes it
delete(serialObject)