function output = rheodyne232objfastcomm(serialObject, command)
% RHEODYNE232OBJFASTCOMM Reads and writes data from Rheodyne valves
% rheodyne232objfastcomm( serialObject, command) reads or writes
% information from/to Rheodyne valves connected via serial port. serialObject
% is the serial port object, and command is the command (as a string). If
% reading a value, responds with the value or a horizontal array of values
% if successfully carried out.  This is the fast version, which means there
% is no waiting for confirmation of the communications.

% Normal usage:

% e.g. rheodyne232objcomm(serialObject, 'S') for the current valve status.

% Range:

% serialObject = valid serial object
% command = string


% checks the number of arguments
error(nargchk(2, 2, nargin))

% error handling
if ~isa(serialObject, 'serial') || ~isvalid(serialObject) || ~strcmp(serialObject.Status, 'open')
    % errors
    error('serialObject must be a valid closed open object.')
end

% flushes out anything in the buffer - this is essential for repeated runs
fread(serialObject);

% sends command
fprintf(serialObject, command, 'async')