function rheodyne232objstart(serialObject)
% RHEODYNE232OBJSTART starts the timer for Rheodyne controllers
% rheodyne232objstart(serialObject) starts the timer for Rheodyne control,
% given a valid timer object.

% e.g. rheodyne232objstart(serialObject) starts the Rheodyne timer for
% the Rheodyne.


% checks the number of arguments
error(nargchk(1, 1, nargin))

% checks the timer is there
if ~isa(serialObject, 'serial') || ~isvalid(serialObject) || ~strcmp(serialObject.Status, 'open')
    % errors
    error('serialObject must be a valid open serial object.')
    
elseif ~isfield(serialObject.UserData, 'timerObject') || ~isa(serialObject.UserData.timerObject, 'timer') || ~isscalar(serialObject.UserData.timerObject) || ~isvalid(serialObject.UserData.timerObject)
    % error
    error('Timer in user data of serial object is not present or is invalid.')
end

% starts it only if it wasn't already running (stops annoying warnings
% coming up)
if ~strcmp(serialObject.UserData.timerObject, 'on')
    % starts the timer
    start(serialObject.UserData.timerObject)
end