function status = rheodyne232objstatus(serialObject)
% RHEODYNE232OBJSTATUS gets the current status of the rheodyne timer object
% status = rheodyne232status(rheodyneTimer) reads if the Rheodyne timer is
% running or not.  rheodyneTimer is the timer object (generated by
% rheodyneobj). status is 1 if the timer is running, and 0 if it is not.

% e.g. status = rheodyne232objstatus(serialObject) - returns the
% current status of the rheodyne timer, e.g. 1 for if it is running.


% checks the number of arguments
error(nargchk(1, 1, nargin))

% checks the timer is there
if ~isa(serialObject, 'serial') || ~isvalid(serialObject) || ~strcmp(serialObject.Status, 'open')
    % errors
    error('serialObject must be a valid open serial object.')
    
elseif ~isfield(serialObject.UserData, 'timerObject') || ~isa(serialObject.UserData.timerObject, 'timer') || ~isscalar(serialObject.UserData.timerObject) || ~isvalid(serialObject.UserData.timerObject)
    % error
    error('Timer in user data of serial object is not present or is invalid.')
end

% returns true only if running
if strcmp(serialObject.UserData.timerObject.running, 'on')
    % true
    status = true;
end