function rheodyne232objstop(serialObject)
% RHEODYNE232OBJSTOP stops the timer for Rheodyne controllers
% rheodyne232objstop(serialObject) stops the timer for Rheodyne control,
% given a valid serial object containing the timer.

% e.g. rheodyne232objstop(serialObject) stops the Rheodyne timer.


% checks the number of arguments
error(nargchk(1, 1, nargin))

% checks the timer is there
if ~isa(serialObject, 'serial') || ~isvalid(serialObject) || ~strcmp(serialObject.Status, 'open')
    % errors
    error('serialObject must be a valid open serial object.')
    
elseif ~isfield(serialObject.UserData, 'timerObject') || ~isa(serialObject.UserData.timerObject, 'timer') || ~isscalar(serialObject.UserData.timerObject) || ~isvalid(serialObject.UserData.timerObject)
    % error
    error('Timer in user data of serial object is not present or is invalid.')
end

% stop it only if it was already running (stops annoying warnings coming
% up)
if strcmp(serialObject.UserData.timerObject.running, 'on')
    % stops the timer
    stop(serialObject.UserData.timerObject)
end